@@ -9,7 +9,11 @@ def getHeaders():
         'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36',
         'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.835.163 Safari/535.1',
         'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0) Gecko/20100101 Firefox/6.0',
-        'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.50 (KHTML, like Gecko) Version/5.1 Safari/534.50'
+        'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/534.50 (KHTML, like Gecko) Version/5.1 Safari/534.50',
+        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36",
+        "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.11 (KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11",
+        "Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.133 Safari/534.16",
+        "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.87 Safari/537.36"
     ]
 
     user_agent = random.choice(user_agent_list)
@@ -21,11 +25,10 @@ def getHeaders():
 def format_datetime(dt):
     try:
         ret = ''
-        pattern = re.compile('\\d{1,2}-\\d{1,2}')
-        pattern2 = re.compile('\\d{4}-\\d{2}-\\d{2}')
-        pattern3 = re.compile('\\d{1,2}:\\d{1,2}')
-        pattern4 = re.compile('\\d{2}月\\d{2}日\\s\\d{2}:\\d{2}')
-        pattern5 = re.compile('(\\d{4}年\\d{2}月\\d{2}日\\s\\d{2}:\\d{2})')
+        pattern = re.compile('\\d+[-年/]+\\d+[-月/]+\\d+[日]?\s?\\d*[:]?\\d*[:]?\\d{1,2}')
+        pattern1 = re.compile('\\d{1,2}[-月]+\\d{1,2}[日]?')
+        pattern2 = re.compile('\\d{1,2}:\\d{1,2}')
+        pattern3 = re.compile('\\d{1,2}[-月/]+\\d{1,2}[日]?[\\s]*\\d{1,2}:\\d{1,2}')
         if '分钟前' in dt:
             # m = int(dt.split('分钟')[0].strip())
             mpattern = re.compile('(\\d+)分钟前')
@@ -51,29 +54,40 @@ def format_datetime(dt):
             ret = datetime.datetime.strftime(df, '%Y-%m-%d %H:%M:%S')
         elif '前天' in dt:
             ret = (datetime.datetime.now() - datetime.timedelta(days=2)).strftime("%Y-%m-%d %H:%M:%S")
-        elif re.match(pattern, dt):
-            strdate = str(datetime.datetime.now().year) + '-' + dt
-            dtformat = datetime.datetime.strptime(strdate, '%Y-%m-%d')
-            ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d')
-        elif re.match(pattern2, dt):
-            dtformat = datetime.datetime.strptime(dt, '%Y-%m-%d')
+        elif re.search(pattern, dt):
+            result = re.search(pattern, dt)
+            r = result.group(0)
+            r = re.sub('[-年月/]', '-', r)
+            r = re.sub('日', '', r).strip()
+            if len(r) <= 10:
+                dtformat = datetime.datetime.strptime(r, '%Y-%m-%d')
+            elif len(r) <= 16:
+                dtformat = datetime.datetime.strptime(r, '%Y-%m-%d %H:%M')
+            elif len(r) <= 19:
+                dtformat = datetime.datetime.strptime(r, '%Y-%m-%d %H:%M:%S')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
-        elif re.match(pattern3, dt):
-            dtformat = datetime.datetime.strftime(datetime.datetime.now(), '%Y-%m-%d') + ' '
-            ret = dtformat + dt
-        elif re.match(pattern4, dt):
+        elif re.search(pattern3, dt):
+            dt = re.search(pattern3, dt).group(0)
             strdate = str(datetime.datetime.now().year) + '-' + dt
-            strdate = strdate.replace('月', '-')
-            ret = strdate.replace('日', '')
-        elif re.match(pattern5, dt):
-            strdate = dt.replace('年', '-')
-            strdate = strdate.replace('月', '-')
-            ret = strdate.replace('日', '')
+            dtformat = re.sub('[月/]', '-', strdate)
+            dtformat = re.sub('日', '', dtformat).strip()
+            dtformat = datetime.datetime.strptime(dtformat, '%Y-%m-%d %H:%M')
+            ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
+        elif re.search(pattern1, dt):
+            dt = re.search(pattern1, dt).group(0)
+            strdate = str(datetime.datetime.now().year) + '-' + dt
+            dtformat = re.sub('[月/]', '-', strdate)
+            dtformat = re.sub('日', '', dtformat).strip()
+            dtformat = datetime.datetime.strptime(strdate, '%Y-%m-%d')
+            ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
+        elif re.search(pattern2, dt):
+            dt = re.search(pattern2, dt).group(0)
+            dtformat = datetime.datetime.strftime(datetime.datetime.now(), '%Y-%m-%d') + ' ' + dt
+            dtformat = datetime.datetime.strptime(dtformat, '%Y-%m-%d %H:%M')
+            ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
         elif '+0800' in dt:
             dtformat = datetime.datetime.strptime(dt, '%a %b %d %H:%M:%S +0800 %Y')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
-        elif '发布时间：' in dt:
-            ret = dt.split('发布时间：')[-1].strip()
         else:
             ret = dt
     except Exception as e:
